@@ -32,7 +32,7 @@ class KStart: public QObject {
 
 public:
   KStart();
-  ~KStart(){}
+  ~KStart() override {}
   
 public Q_SLOTS:
   void windowAdded(WId);
